@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10914 2018-03-21 13:34:21Z David $
+# $Id: __init__.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,11 +11,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-21 21:34:21 +0800 (週三, 21 三月 2018) $
-# $Revision: 10914 $
+# $Author: Andy $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
-from django.conf.urls import url, include, patterns
+from django.conf.urls import url, include
 
 def attachURLs(settings, urlpatterns):
     """
@@ -28,17 +28,17 @@ def attachURLs(settings, urlpatterns):
 
     # Theophrastus newsletter document url
     if 'Theophrastus.document' in settings.INSTALLED_APPS:
-        urlpatterns += patterns('',
+        urlpatterns += [
             url(r'^admin/', include('Theophrastus.document.urls')),
-        )
+        ]
 
     # Theophrastus newsletter urls
-    urlpatterns += patterns('',
+    urlpatterns += [
         url(r'^newsletters/', include('Theophrastus.urls')),
-    )
+    ]
     
     # Tinymic editor.
     if 'Theophrastus.editor' in settings.INSTALLED_APPS:
-        urlpatterns += patterns('',
+        urlpatterns += [
             url(r'^tinymce/', include('tinymce.urls')),
-        )
\ No newline at end of file
+        ]
\ No newline at end of file
