@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 11617 2019-06-07 05:01:17Z Andy $
+# $Id: Mailer.py 12366 2020-06-19 06:41:16Z Andy $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: Andy $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 11617 $
+# $Revision: 12366 $
 
 import os
 import re
@@ -36,7 +36,7 @@ from django.contrib.sites.models import Site
 from django.template import Context
 from django.template.loader import render_to_string
 from django.conf import settings
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 
 from emencia.django.newsletter.mailer import Mailer
 from emencia.django.newsletter.utils.tokens import tokenize
