@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 9653 2016-04-27 06:09:22Z Judy $
+# $Id: urls.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,11 +11,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
-# $Date: 2016-04-27 14:09:22 +0800 (週三, 27 四月 2016) $
-# $Revision: 9653 $
+# $Author: Andy $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
-from django.conf.urls import url, patterns
+from django.conf.urls import url
 
 from Iuppiter.extension.views import getDoc
 
@@ -26,9 +26,9 @@ from Iuppiter.extension.views import getDoc
 #       (r'^admin/', include('Theophrastus.document.urls')),
 #   )
 
-urlpatterns = patterns('',
+urlpatterns = [
     # Document.
     url(r'^document/(?P<name>\w+)/$', getDoc, {
         'dir': 'docs',
     }, name='Theophrastus.views.document'),
-)
+]
