@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 10797 2018-03-01 02:31:02Z David $
+# $Id: admin.py 12366 2020-06-19 06:41:16Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,13 +11,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-01 10:31:02 +0800 (週四, 01 三月 2018) $
-# $Revision: 10797 $
+# $Author: Andy $
+# $Date: 2020-06-19 14:41:16 +0800 (週五, 19 六月 2020) $
+# $Revision: 12366 $
 
 from django.contrib import admin
 from django.contrib.admin.views.main import ChangeList
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext as _
 
 from emencia.django.newsletter.models import Newsletter
