@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11616 2019-06-07 02:15:46Z Andy $
+# $Id: admin.py 12366 2020-06-19 06:41:16Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,15 +12,16 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
-# $Revision: 11616 $
+# $Date: 2020-06-19 14:41:16 +0800 (週五, 19 六月 2020) $
+# $Revision: 12366 $
 
 from django import forms
 from django.contrib import admin
 from django.utils.translation import ugettext as _
 from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
-from django.core.urlresolvers import reverse
+from django.urls import reverse
+from django.utils.html import format_html
 
 from emencia.django.newsletter.models import Newsletter
 from emencia.django.newsletter.admin import NewsletterAdmin
@@ -57,11 +58,11 @@ class NewsletterForm(forms.ModelForm):
             if header:
                 headerTitle = header.title
             else:
-                headerTitle = Header.objects.get(pk=1).title
+                headerTitle = Header.objects.first().title
             if footer:
                 footerTitle = footer.title
             else:
-                footerTitle = Footer.objects.get(pk=1).title
+                footerTitle = Footer.objects.first().title
             
             sender = newsletterObj[0].header_sender
             reply = newsletterObj[0].header_reply
@@ -76,8 +77,8 @@ class NewsletterForm(forms.ModelForm):
                 'NEWSLETTER_DEFAULT_HEADER_REPLY',
                 "Nuwa<service@tracedig.com>"
             )
-            headerTitle = Header.objects.get(pk=1).title
-            footerTitle = Footer.objects.get(pk=1).title
+            headerTitle = Header.objects.first().title
+            footerTitle = Footer.objects.first().title
 
         super(NewsletterForm, self).__init__(*args, **kwargs)
         self.fields['header_sender'].initial = sender
@@ -180,14 +181,14 @@ class NewsletterExtensionAdmin(NewsletterAdmin):
             mailingList = obj.mailing_list
             url = reverse('admin:newsletter_mailinglist_change', args=(mailingList.id,))
             
-            return u"<a href='%s'>%s</a>" % (url, mailingList.name)
+            return format_html(u"<a href='%s'>%s</a>" % (url, mailingList.name))
 
     def getServer(self, obj):
         if obj:
             server = obj.server
             url = reverse('admin:newsletter_smtpserver_change', args=(server.id,))
     
-            return u"<a href='%s'>%s</a>" % (url, server.name)
+            return format_html(u"<a href='%s'>%s</a>" % (url, server.name))
 
     getMailingList.short_description = _('mailing list')
     getMailingList.allow_tags = True
