@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10797 2018-03-01 02:31:02Z David $
+# $Id: views.py 11006 2018-05-01 07:48:58Z Kevin $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,11 +11,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
-# $Revision: 10797 $
+# $Author: Kevin $
+# $Date: 2018-05-01 15:48:58 +0800 (週二, 01 五月 2018) $
+# $Revision: 11006 $
 
-from django.db.models import Max as modelsMax
+from django.db.models import Q, Max as modelsMax
 from django.contrib.admin.views.decorators import staff_member_required
 from django.http import Http404
 
@@ -86,8 +86,16 @@ def getHistory(request, slug):
         condition.update({'status': int(status)})
 
     keyword = request.GET.get('keyword', '')
+
     if keyword:
-        condition.update({'contact__email__icontains': keyword})
+        condition.update({
+            'QList': [
+                Q(contact__first_name__icontains=keyword)
+                | Q(contact__last_name__icontains=keyword)
+                | Q(contact__email__icontains=keyword)
+                | Q(contact__tags__icontains=keyword)
+            ]
+        })
 
     response = getSubscriberHistory(request.GET, condition)
     return response
